#
# spec file for package openmw
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# older boost versions (<= 1.66) available on openSUSE <= 15.5 break
# compilation because openmw uses -std=c++20 and these older boost versions
# are not compatible with it
# 1.69 is the first boost version that is supposed to work with C++ 20:
%define min_boost_version 1.69
Name:           openmw
Version:        0.49.0
Release:        1.1
Summary:        Reimplementation of The Elder Scrolls III: Morrowind
License:        GPL-3.0-only AND MIT
Group:          Amusements/Games/RPG
URL:            https://www.openmw.org
Source:         https://github.com/OpenMW/openmw/archive/refs/tags/%{name}-%{version}.tar.gz
Source2:        %{name}.rpmlintrc
BuildRequires:  MyGUI-devel >= 3.2.1
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  libboost_filesystem-devel >= %{min_boost_version}
BuildRequires:  libboost_iostreams-devel >= %{min_boost_version}
BuildRequires:  libboost_program_options-devel >= %{min_boost_version}
BuildRequires:  libboost_regex-devel >= %{min_boost_version}
BuildRequires:  libboost_system-devel >= %{min_boost_version}
BuildRequires:  tinyxml-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Linguist)
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6OpenGLWidgets)
BuildRequires:  pkgconfig(Qt6Svg)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(bullet) >= 2.83.0
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libunshield)
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(openscenegraph) >= 3.2
BuildRequires:  pkgconfig(openthreads) >= 3.2
BuildRequires:  pkgconfig(recastnavigation) >= 1.6.0
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(yaml-cpp)
Requires:       OpenSceneGraph-plugin-collada
Requires:       OpenSceneGraph-plugins
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc11
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif

%description
OpenMW is a new and modern engine based on the one that runs the 2002 open-world RPG Morrowind. The engine (OpenMW) will come with its own editor (OpenCS) which will allow the user to edit or create their own games. Both OpenCS and OpenMW are written from scratch and aren’t made to support any third party programs the original Morrowind engine uses to improve its functionality.
To give you a better idea of what this project is about, here are some of the aims for the future of the OpenMW engine:

  * Be a full-featured reimplementation of the Morrowind engine.
  * Run natively on Windows, Linux and MacOS X.
  * Support all existing content, including Tribunal, Bloodmoon and all user created mods (in case they don’t
     use external programs).
  * Allow much greater modability: change game rules, create new spell effects, etc. through scripting.
  * Fix system design bugs, like save-game “doubling” problem.
  * Improve the interface and journal system.
  * Improved graphics by taking advantage of more modern hardware.
  * Support to improve game mechanics, physics, combat and AI.
  * (Possibly) Support to implement multiplayer
  * (Possibly) Support to run on mobile devices.

NOTE(!!!): Playing Morrowind with this engine STILL REQUIRES one to own the Morrowind data files.

OpenCS will support the editing of all OpenMW features. We aim for the editor to stay fully up-to-date with the corresponding OpenMW version, allowing the user to edit any newly implemented features. Post v1.0 features are going to be the use of OpenCS as a debugging tool for OpenMW content and the support for editor plugins.
These are files that add to the editor code, improving its functionality to allow it to have some nice extras.
The OpenCS is not based on the editing tool which came with the original Morrowind game, it is a program made by modders for modders. Important properties of the OpenCS are:

 * non-blocking
 * multi-threaded
 * multi-document support
 * multi-view support
 * high scalability
 * customisable GUI

%prep
%autosetup -p1 -n %{name}-%{name}-%{version}
cp 'files/data/fonts/DejaVuFontLicense.txt' ./DejaVuFontLicense.txt

## fix __DATE__ and __TIME__
STATIC_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
STATIC_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')

%define _sed_work sed -i -e 's/__DATE__/"$STATIC_BUILDDATE"/' -e 's/__TIME__/"$STATIC_BUILDTIME"/'
%{_sed_work} apps/launcher/maindialog.cpp
# Fix line endings
for file in tables.tex main.tex recordtypes.tex filters.tex creating_file.tex files_and_directories.tex windows.tex; do
	sed -i "s/\r$//" "manual/opencs/$file"
done

%build
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
export CC="gcc-11"
export CXX="g++-11"
%endif
# -DBT_USE_DOUBLE_PRECISION should be discovered by cmake from bullet config, but it's not.

%cmake \
       -DCMAKE_C_FLAGS="%{optflags} -DBT_USE_DOUBLE_PRECISION" \
       -DCMAKE_CXX_FLAGS="%{optflags} -DBT_USE_DOUBLE_PRECISION" \
       -DGLOBAL_DATA_PATH="%{_datadir}/" \
       -DMORROWIND_DATA_FILES="%{_datadir}/%{name}/data/" \
       -DOPENMW_RESOURCE_FILES="%{_datadir}/%{name}/resources/" \
       -DUSE_SYSTEM_TINYXML="ON" \
       -DDESIRED_QT_VERSION=5 \
       -DCMAKE_POLICY_DEFAULT_CMP0063=NEW \
       -DCMAKE_CXX_VISIBILITY_PRESET=hidden \
       -DCMAKE_VISIBILITY_INLINES_HIDDEN=1 \
       -DOPENMW_USE_SYSTEM_RECASTNAVIGATION="ON" \
       -DOPENMW_USE_SYSTEM_ICU="ON"

%make_build

%install
%cmake_install

## set the default data location
sed -i -e 's#data="?global?.*$#data="%{_datadir}/%{name}/data"#' \
 %{buildroot}%{_sysconfdir}/%{name}/%{name}.cfg || exit 1

## Install data
cp -pr files/launcher %{buildroot}%{_datadir}/%{name}/resources/ || exit 1

## Install docs
rm -f manual/opencs/.gitignore
rm -Rf %{buildroot}%{_datadir}/licenses/%{name}

## fix location of appdata
mkdir -p %{buildroot}/%{_datadir}/appdata
mv %{buildroot}/%{_datadir}/metainfo/* %{buildroot}/%{_datadir}/appdata/
rm -Rf %{buildroot}/%{_datadir}/metainfo

%suse_update_desktop_file org.openmw.launcher
%suse_update_desktop_file org.openmw.cs
%fdupes %{buildroot}%{_datadir}

%post
/sbin/ldconfig
%desktop_database_post

%postun
/sbin/ldconfig
%desktop_database_postun

%files
%license LICENSE DejaVuFontLicense.txt
%doc README.md
%doc CHANGELOG.md
%doc AUTHORS.md

%doc manual/opencs/*
%config %{_sysconfdir}/%{name}/defaults-cs.bin
%{_bindir}/%{name}-cs

%dir %{_datadir}/%{name}
%dir %{_sysconfdir}/%{name}
%{_datadir}/pixmaps/*.png
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}/*
%dir %{_datadir}/appdata
%{_datadir}/appdata/openmw.appdata.xml
%config(noreplace) %{_sysconfdir}/%{name}/openmw.cfg
%config(noreplace) %{_sysconfdir}/%{name}/gamecontrollerdb*.txt
%config %{_sysconfdir}/%{name}/defaults.bin

%{_bindir}/bsatool
%{_bindir}/esmtool
%{_bindir}/niftest
%{_bindir}/%{name}
%{_bindir}/%{name}-bulletobjecttool
%{_bindir}/%{name}-essimporter
%{_bindir}/%{name}-iniimporter
%{_bindir}/%{name}-launcher
%{_bindir}/%{name}-navmeshtool
%{_bindir}/%{name}-wizard

%changelog
* Fri Jul  4 2025 Michael Pujos <pujos.michael@gmail.com>
- Update to 0.49.0 final
  * Detailed changelog since 0.48.0 available at https://openmw.org/2025/openmw-0-49-0-released
* Mon Jun 23 2025 Michael Pujos <pujos.michael@gmail.com>
- Compiled with Qt6
- Update to version 0.49rc9
  * [#8039] Fixed movement accumulation for actors that use Collada models on some builds compiled under LLVM
  * [#8558] OpenMW-Lua: Light record color is now exposed as util.color rather than as a number
  * [#8559] ESSImporter: Fixed selected spell/enchanted item and stolen item counter conversion
  * [#8563] Improved handling of content files that are defined in the non-user version of openmw.cfg
  * [#8567] Token replacement and relative paths work properly when the paths are passed through CLI
  * Improved application detection for default shortcuts
* Sat Jun  7 2025 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.49rc8. Changes since v0.48.0:
  * Bug #2623: Snowy Granius doesn't prioritize conjuration spells
  * Bug #3438: NPCs can't hit bull netch with melee weapons
  * Bug #3842: Body part skeletons override the main skeleton
  * Bug #4127: Weapon animation looks choppy
  * Bug #4204: Dead slaughterfish doesn't float to water surface after loading saved game
  * Bug #4207: RestoreHealth/Fatigue spells have a huge priority even if a success chance is near 0
  * Bug #4289: Script compilation fails if an NPC deleted in a content file is disabled
  * Bug #4382: Sound output device does not change when it should
  * Bug #4508: Can't stack enchantment buffs from different instances of the same self-cast generic magic apparel
  * Bug #4610: Casting a Bound Weapon spell cancels the casting animation by equipping the weapon prematurely
  * Bug #4683: Disposition decrease when player commits crime is not implemented properly
  * Bug #4710: Object tooltips don't always stick to the top of the object
  * Bug #4742: Actors with wander never stop walking after Loopgroup Walkforward
  * Bug #4743: PlayGroup doesn't play non-looping animations correctly
  * Bug #4754: Stack of ammunition cannot be equipped partially
  * Bug #4816: GetWeaponDrawn returns 1 before weapon is attached
  * Bug #4822: Non-weapon equipment and body parts can't inherit time from parent animation
  * Bug #4898: Odd/Incorrect lighting on meshes
  * Bug #5057: Weapon swing sound plays at same pitch whether it hits or misses
  * Bug #5062: Root bone rotations for NPC animation don't work the same as for creature animation
  * Bug #5065: Actors with scripted animation still try to wander and turn around without moving
  * Bug #5066: Quirks with starting and stopping scripted animations
  * Bug #5129: Stuttering animation on Centurion Archer
  * Bug #5280: Unskinned shapes in skinned equipment are rendered in the wrong place
  * Bug #5371: Keyframe animation tracks are used for any file that begins with an X
  * Bug #5413: Enemies do a battlecry everytime the player summons a creature
  * Bug #5714: Touch spells cast using ExplodeSpell don't always explode
  * Bug #5755: Reset friendly hit counter
  * Bug #5849: Paralysis breaks landing
  * Bug #5870: Disposing of actors who were selected in the console doesn't deselect them like vanilla
  * Bug #5883: Immobile creatures don't cause water ripples
  * Bug #5977: Fatigueless NPCs' corpse underwater changes animation on game load
  * Bug #6025: Subrecords cannot overlap records
  * Bug #6027: Collisionshape becomes spiderweb-like when the mesh is too complex
  * Bug #6146: Lua command `actor:setEquipment` doesn't trigger mwscripts when equipping or unequipping a scripted item
  * Bug #6156: 1ft Charm or Sound magic effect vfx doesn't work properly
  * Bug #6190: Unintuitive sun specularity time of day dependence
  * Bug #6222: global map cell size can crash openmw if set to too high a value
  * Bug #6240: State sharing sometimes prevents the use of the same texture file for different purposes in shaders
  * Bug #6313: Followers with high Fight can turn hostile
  * Bug #6402: The sound of a thunderstorm does not stop playing after entering the premises
  * Bug #6427: Enemy health bar disappears before damaging effect ends
  * Bug #6550: Cloned body parts don't inherit texture effects
  * Bug #6574: Crash at far away from world origin coordinates
  * Bug #6645: Enemy block sounds align with animation instead of blocked hits
  * Bug #6657: Distant terrain tiles become black when using FWIW mod
  * Bug #6661: Saved games that have no preview screenshot cause issues or crashes
  * Bug #6665: The kobolds in the skyrim: home of the nords mod are oversized
  * Bug #6716: mwscript comparison operator handling is too restrictive
  * Bug #6723: "Turn to movement direction" makes the player rotate wildly with COLLADA
  * Bug #6754: Beast to Non-beast transformation mod is not working on OpenMW
  * Bug #6758: Main menu background video can be stopped by opening the options menu
  * Bug #6807: Ultimate Galleon is not working properly
  * Bug #6846: Launcher only works with default config paths
  * Bug #6893: Lua: Inconsistent behavior with actors affected by Disable and SetDelete commands
  * Bug #6894: Added item combines with equipped stack instead of creating a new unequipped stack
  * Bug #6932: Creatures flee from my followers and we have to chase after them
  * Bug #6939: OpenMW-CS: ID columns are too short
  * Bug #6949: Sun Damage effect doesn't work in quasi exteriors
  * Bug #6964: Nerasa Dralor Won't Follow
  * Bug #6973: Fade in happens after the scene load and is shown
  * Bug #6974: Only harmful effects are reflected
  * Bug #6977: Sun damage implementation does not match research
  * Bug #6985: Issues with Magic Cards numbers readability
  * Bug #6986: Sound magic effect does not make noise
  * Bug #6987: Set/Mod Blindness should not darken the screen
  * Bug #6992: Crossbow reloading doesn't look the same as in Morrowind
  * Bug #6993: Shooting your last round of ammunition causes the attack animation to cancel
  * Bug #7009: Falling actors teleport to the ground without receiving any damage on cell loading
  * Bug #7013: Local map rendering in some cells is broken
  * Bug #7034: Misc items defined in one content file are not treated as keys if another content file uses them as such
  * Bug #7040: Incorrect rendering order for Rebirth's Stormfang
  * Bug #7042: Weapon follow animations that immediately follow the hit animations cause multiple hits
  * Bug #7044: Changing a class' services does not affect autocalculated NPCs
  * Bug #7051: Collada animated character models are optimized out of the collision box instance with object paging
  * Bug #7053: Running into objects doesn't trigger GetCollidingPC
  * Bug #7054: Quests aren't sorted by name
  * Bug #7064: NPCs don't report crime if the player is casting offensive spells on them while sneaking
  * Bug #7077: OpenMW fails to load certain particle effects in .osgt format
  * Bug #7084: Resurrecting an actor doesn't take into account base record changes
  * Bug #7088: Deleting last save game of last character doesn't clear character name/details
  * Bug #7092: BSA archives from higher priority directories don't take priority
  * Bug #7102: Some HQ Creatures mod models can hit the 8 texture slots limit with 0.48
  * Bug #7103: Multiple paths pointing to the same plugin but with different cases lead to automatically removed config entries
  * Bug #7122: Teleportation to underwater should cancel active water walking effect
  * Bug #7131: MyGUI log spam when post processing HUD is open
  * Bug #7134: Saves with an invalid last generated RefNum can be loaded
  * Bug #7145: Normals passed to post-processing shaders are broken
  * Bug #7146: Debug draw for normals is wrong
  * Bug #7163: Myar Aranath: Wheat breaks the GUI
  * Bug #7168: Fix average scene luminance
  * Bug #7172: Current music playlist continues playing indefinitely if next playlist is empty
  * Bug #7202: Post-processing normals for terrain, water randomly stop rendering
  * Bug #7204: Missing actor scripts freeze the game
  * Bug #7229: Error marker loading failure is not handled
  * Bug #7243: Supporting loading external files from VFS from esm files
  * Bug #7284: "Your weapon has no effect." message doesn't always show when the player character attempts to attack
  * Bug #7292: Weather settings for disabling or enabling snow and rain ripples don't work
  * Bug #7298: Water ripples from projectiles sometimes are not spawned
  * Bug #7307: Alchemy "Magic Effect" search string does not match on tool tip for effects related to attributes
  * Bug #7309: Sunlight scattering is visible in inappropriate situations
  * Bug #7322: Shadows don't cover groundcover depending on the view angle and perspective with compute scene bounds = primitives
  * Bug #7351: Unsupported MSAA level fallback wrecks GL context extension checks
  * Bug #7353: Normal Map Crashes with Starwind Assets in TES3MP and OpenMW
  * Bug #7354: Disabling post processing in-game causes a crash
  * Bug #7364: Post processing is not reflected in savegame previews
  * Bug #7380: NiZBufferProperty issue
  * Bug #7413: Generated wilderness cells don't spawn fish
  * Bug #7415: Unbreakable lock discrepancies
  * Bug #7416: Modpccrimelevel is different from vanilla
  * Bug #7428: AutoCalc flag is not used to calculate enchantment costs
  * Bug #7447: OpenMW-CS: Dragging a cell of a different type (from the initial type) into the 3D view crashes OpenMW-CS
  * Bug #7450: Evading obstacles does not work for actors missing certain animations
  * Bug #7459: Icons get stacked on the cursor when picking up multiple items simultaneously
  * Bug #7469: Reloading lua with a orphaned lua UI element causes crash
  * Bug #7472: Crash when enchanting last projectiles
  * Bug #7475: Equipping a constant effect item doesn't update the magic menu
  * Bug #7502: Data directories dialog (0.48.0) forces adding subdirectory instead of intended directory
  * Bug #7505: Distant terrain does not support sample size greater than cell size
  * Bug #7531: Some bitmap font glyph substitutes are erroneous or missing
  * Bug #7535: Bookart paths for textures in OpenMW vs vanilla Morrowind
  * Bug #7548: Actors cannot open doors that were teleported from a different cell
  * Bug #7553: Faction reaction loading is incorrect
  * Bug #7557: Terrain::ChunkManager::createChunk is called twice for the same position, lod on initial loading
  * Bug #7573: Drain Fatigue can't bring fatigue below zero by default
  * Bug #7582: Skill specializations are hardcoded in character creation
  * Bug #7585: Difference in interior lighting between OpenMW with legacy lighting method enabled and vanilla Morrowind
  * Bug #7587: Quick load related crash
  * Bug #7603: Scripts menu size is not updated properly
  * Bug #7604: Goblins Grunt becomes idle once injured
  * Bug #7609: ForceGreeting should not open dialogue for werewolves
  * Bug #7611: Beast races' idle animations slide after turning or jumping in place
  * Bug #7617: The death prompt asks the player if they wanted to load the character's last created save
  * Bug #7619: Long map notes may get cut off
  * Bug #7623: Incorrect placement of the script info in the engraved ring of healing tooltip
  * Bug #7627: Сrash at the start
  * Bug #7630: Charm can be cast on creatures
  * Bug #7631: Cannot trade with/talk to Creeper or Mudcrab Merchant when they're fleeing
  * Bug #7633: Groundcover should ignore non-geometry Drawables
  * Bug #7636: Animations bug out when switching between 1st and 3rd person, while playing a scripted animation
  * Bug #7637: Actors can sometimes move while playing scripted animations
  * Bug #7639: NPCs don't use hand-to-hand if their other melee skills were damaged during combat
  * Bug #7641: loopgroup loops the animation one time too many for actors
  * Bug #7642: Items in repair and recharge menus aren't sorted alphabetically
  * Bug #7643: Can't enchant items with constant effect on self magic effects for non-player character
  * Bug #7646: Follower voices pain sounds when attacked with magic
  * Bug #7647: NPC walk cycle bugs after greeting player
  * Bug #7654: Tooltips for enchantments with invalid effects cause crashes
  * Bug #7660: Some inconsistencies regarding Invisibility breaking
  * Bug #7661: Player followers should stop attacking newly recruited actors
  * Bug #7665: Alchemy menu is missing the ability to deselect and choose different qualities of an apparatus
  * Bug #7675: Successful lock spell doesn't produce a sound
  * Bug #7676: Incorrect magic effect order in alchemy
  * Bug #7679: Scene luminance value flashes when toggling shaders
  * Bug #7685: Corky sometimes doesn't follow Llovyn Andus
  * Bug #7696: Freeze in CompositeMapRenderer::drawImplementation
  * Bug #7707: (OpenCS): New landscape records do not contain appropriate flags
  * Bug #7712: Casting doesn't support spells and enchantments with no effects
  * Bug #7721: CS: Special Chars Not Allowed in IDs
  * Bug #7723: Assaulting vampires and werewolves shouldn't be a crime
  * Bug #7724: Guards don't help vs werewolves
  * Bug #7728: Fatal Error at Startup
  * Bug #7733: Launcher shows incorrect data paths when there's two plugins with the same name
  * Bug #7737: OSG stats are missing some data on loading screens
  * Bug #7742: Governing attribute training limit should use the modified attribute
  * Bug #7744: Player base record cannot have weapons in the inventory
  * Bug #7753: Editor: Actors Don't Scale According to Their Race
  * Bug #7758: Water walking is not taken into account to compute path cost on the water
  * Bug #7761: Rain and ambient loop sounds are mutually exclusive
  * Bug #7763: Bullet shape loading problems, assorted
  * Bug #7765: OpenMW-CS: Touch Record option is broken
  * Bug #7769: Sword of the Perithia: Broken NPCs
  * Bug #7770: Sword of the Perithia: Script execution failure
  * Bug #7780: Non-ASCII texture paths in NIF files don't work
  * Bug #7785: OpenMW-CS initialising Skill and Attribute fields to 0 instead of -1 on non-FortifyStat spells
  * Bug #7787: Crashing when loading a saved game (not always though)
  * Bug #7794: Fleeing NPCs name tooltip doesn't appear
  * Bug #7796: Absorbed enchantments don't restore magicka
  * Bug #7823: Game crashes when launching it.
  * Bug #7832: Ingredient tooltips show magnitude for Fortify Maximum Magicka effect
  * Bug #7840: First run of the launcher doesn't save viewing distance as the default value
  * Bug #7841: Editor: "Dirty" water heights are saved in modified CELLs
  * Bug #7859: AutoCalc flag is not used to calculate potion value
  * Bug #7861: OpenMW-CS: Incorrect DIAL's type in INFO records
  * Bug #7872: Region sounds use wrong odds
  * Bug #7886: Equip and unequip animations can't share the animation track section
  * Bug #7887: Editor: Mismatched reported script data size and actual data size causes a crash during save
  * Bug #7891: Launcher Reverts 8k Shadows to default
  * Bug #7896: Editor: Loading cellrefs incorrectly transforms Refnums, causing load failures
  * Bug #7898: Editor: Invalid reference scales are allowed
  * Bug #7899: Editor: Doors can't be unlocked
  * Bug #7901: Editor: Teleport-related fields shouldn't be editable if a ref does not teleport
  * Bug #7908: Key bindings names in the settings menu are layout-specific
  * Bug #7912: Lua: castRenderingRay fails to hit height map
  * Bug #7943: Using "addSoulGem" and "dropSoulGem" commands to creatures works only with "Weapon & Shield" flagged ones
  * Bug #7950: Crash in MWPhysics::PhysicsTaskScheduler::removeCollisionObject
  * Bug #7970: Difference of GetPCSleep (?) behavior between vanilla and OpenMW
  * Bug #7980: Paralyzed NPCs' lips move
  * Bug #7993: Cannot load Bloodmoon without Tribunal
  * Bug #7997: Can toggle perspective when paralyzed
  * Bug #8002: Portable light sources held by creatures do not emit lighting
  * Bug #8005: F3 stats bars are sorted not according to their place in the timeline
  * Bug #8018: Potion effects should never explode and always apply on self
  * Bug #8021: Player's scale doesn't reset when starting a new game
  * Bug #8048: Actors can generate negative collision extents and have no collision
  * Bug #8063: menu_background.bik video with audio freezes the game forever
  * Bug #8064: Lua move360 script doesn't respect the enableZoom/disableZoom Camera interface setting
  * Bug #8085: Don't search in scripts or shaders directories for "Select directories you wish to add" menu in launcher
  * Bug #8097: GetEffect doesn't detect 0 magnitude spells
  * Bug #8099: Reaching Lua memory limit leads to a crash
  * Bug #8124: Normal weapon resistance is applied twice for NPCs
  * Bug #8132: Actors without hello responses turn to face the player
  * Bug #8171: Items with more than 100%% health can be repaired
  * Bug #8172: Openmw-cs crashes when viewing `Dantooine, Sea`
  * Bug #8187: Intervention effects should use Chebyshev distance to determine the closest marker
  * Bug #8189: The import tab in the launcher doesn't remember the checkbox selection
  * Bug #8191: NiRollController does not work for sheath meshes
  * Bug #8206: Moving away from storm wind origin should make you faster
  * Bug #8207: Using hand-to-hand while sneaking plays the critical hit sound when the target is not getting hurt
  * Bug #8208: The launcher's view distance option's minimum value isn't capped to Vanilla's minimum
  * Bug #8223: Ghosts don't move while spellcasting
  * Bug #8231: AGOP doesn't like NiCollisionSwitch
  * Bug #8237: Non-bipedal creatures should *not* use spellcast equip/unequip animations
  * Bug #8252: Plugin dependencies are not required to be loaded
  * Bug #8295: Post-processing chain is case-sensitive
  * Bug #8299: Crash while smoothing landscape
  * Bug #8364: Crash when clicking scrollbar without handle (divide by zero)
  * Bug #8378: Korean bitmap fonts are unusable
  * Bug #8439: Creatures without models can crash the game
  * Bug #8441: Freeze when using video main menu replacers
  * Bug #8445: Launcher crashes on exit when cell name loading thread is still running
  * Bug #8462: Crashes when resizing the window on macOS
  * Bug #8465: Blue screen w/ antialiasing and post-processing on macOS
  * Bug #8503: Camera does not handle NaN gracefully
  * Bug #8541: Lua: util.color:asHex produces wrong output for some colors
  * Feature #1415: Infinite fall failsafe
  * Feature #2566: Handle NAM9 records for manual cell references
  * Feature #3501: OpenMW-CS: Instance Editing - Shortcuts for axial locking
  * Feature #3537: Shader-based water ripples
  * Feature #5173: Support for NiFogProperty
  * Feature #5492: Let rain and snow collide with statics
  * Feature #5926: Refraction based on water depth
  * Feature #5944: Option to use camera as sound listener
  * Feature #6009: Animation blending - smooth animation transitions with modding support
  * Feature #6152: Playing music via lua scripts
  * Feature #6188: Specular lighting from point light sources
  * Feature #6411: Support translations in openmw-launcher
  * Feature #6447: Add LOD support to Object Paging
  * Feature #6491: Add support for Qt6
  * Feature #6505: UTF-8 support in Lua scripts
  * Feature #6556: Lua API for sounds
  * Feature #6679: Design a custom Input Action API
  * Feature #6726: Lua API for creating new objects
  * Feature #6727: Lua API for records of all object types
  * Feature #6823: Animation layering for osgAnimation formats
  * Feature #6864: Lua file access API
  * Feature #6922: Improve launcher appearance
  * Feature #6933: Support high-resolution cursor textures
  * Feature #6945: Support S3TC-compressed and BGR/BGRA NiPixelData
  * Feature #6979: Add support of loading and displaying LOD assets purely based on their filename extension
  * Feature #6983: PCVisionBonus script functions
  * Feature #6995: Localize the "show effect duration" option
  * Feature #7058: Implement TestModels (T3D) console command
  * Feature #7087: Block resolution change in the Windowed Fullscreen mode
  * Feature #7091: Allow passing `initData` to the :addScript call
  * Feature #7125: Remembering console commands between sessions
  * Feature #7129: Add support for non-adaptive VSync
  * Feature #7130: Ability to set MyGUI logging verbosity
  * Feature #7142: MWScript Lua API
  * Feature #7148: Optimize string literal lookup in mwscript
  * Feature #7160: Editor: Moving the Response column of Topicinfos in a better place
  * Feature #7161: OpenMW-CS: Make adding and filtering TopicInfos easier
  * Feature #7180: Rename water_nm file and move it to the vfs
  * Feature #7194: Ori to show texture paths
  * Feature #7214: Searching in the in-game console
  * Feature #7245: Expose the argument `cancelOther` of `AiSequence::stack` to Lua
  * Feature #7248: Searching in the console with regex and toggleable case-sensitivity
  * Feature #7318: Ability to disable water culling
  * Feature #7468: Factions API for Lua
  * Feature #7477: NegativeLight Magic Effect flag
  * Feature #7499: OpenMW-CS: Generate record filters by drag & dropping cell content to the filters field
  * Feature #7538: Lua API for advancing skills
  * Feature #7546: Start the game on Fredas
  * Feature #7554: Controller binding for tab for menu navigation
  * Feature #7568: Uninterruptable scripted music
  * Feature #7590: [Lua] Ability to deserialize YAML data from scripts
  * Feature #7606: Launcher: allow Shift-select in Archives tab
  * Feature #7608: Make the missing dependencies warning when loading a savegame more helpful
  * Feature #7618: Show the player character's health in the save details
  * Feature #7625: Add some missing console error outputs
  * Feature #7634: Support NiParticleBomb
  * Feature #7648: Lua Save game API
  * Feature #7652: Sort inactive post processing shaders list properly
  * Feature #7698: Implement sAbsorb, sDamage, sDrain, sFortify and sRestore
  * Feature #7709: Improve resolution selection in Launcher
  * Feature #7777: Support external Bethesda material files (BGSM/BGEM)
  * Feature #7788: [Lua] Add ignore option to nearby.castRenderingRay
  * Feature #7792: Support Timescale Clouds
  * Feature #7795: Support MaxNumberRipples INI setting
  * Feature #7805: Lua Menu context
  * Feature #7860: Lua: Expose NPC AI settings (fight, alarm, flee)
  * Feature #7875: Disable MyGUI windows snapping
  * Feature #7914: Do not allow to move GUI windows out of screen
  * Feature #7916: Expose all AiWander options to Lua, extend other packages as well
  * Feature #7923: Don't show non-existent higher ranks for factions with fewer than 9 ranks
  * Feature #7932: Support two-channel normal maps
  * Feature #7936: Scalable icons in Qt applications
  * Feature #7953: Allow to change SVG icons colors depending on color scheme
  * Feature #7964: Add Lua read access to MW Dialogue records
  * Feature #7971: Make save's Time Played value display hours instead of days
  * Feature #7985: Support dark mode on Windows
  * Feature #8038: (Lua) Containers should have respawning/organic flags
  * Feature #8067: Support Game Mode on macOS
  * Feature #8078: OpenMW-CS Terrain Equalize Tool
  * Feature #8087: Creature movement flags are not exposed
  * Feature #8092: Lua - Vector swizzling
  * Feature #8109: Expose commitCrime to Lua API
  * Feature #8130: Launcher: Add the ability to open a selected data directory in the file browser
  * Feature #8145: Starter spell flag is not exposed
  * Feature #8286: Launcher: Preserve semantically identical openmw.cfg
  * Feature #8287: Launcher: Special handling for comma in openmw.cfg entries is unintuitive and should be removed
  * Task #5859: User openmw-cs.cfg has comment talking about settings.cfg
  * Task #5896: Do not use deprecated MyGUI properties
  * Task #6085: Replace boost::filesystem with std::filesystem
  * Task #6149: Dehardcode Lua API_REVISION
  * Task #6624: Drop support for saves made prior to 0.45
  * Task #7048: Get rid of std::bind
  * Task #7113: Move from std::atoi to std::from_char
  * Task #7117: Replace boost::scoped_array with std::vector
  * Task #7151: Do not use std::strerror to get errno error message
  * Task #7182: FFMpeg 5.1.1+ support
  * Task #7394: Drop support for --fs-strict
  * Task #7720: Drop 360-degree screenshot support
  * Task #8141: Merge Instance Drop Modes
  * Task #8214: Drop script blacklisting functionality
* Mon Mar 17 2025 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.49rc6
* Wed Feb 19 2025 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.49rc5
* Mon Feb  3 2025 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.49rc4
* Fri Sep 13 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to git version as of Sept 13th 2024. Fixes compilation issue
  with internal component osg-ffmpeg-videoplayer
- Re-enabled compilation of openmw-cs
* Fri Feb  2 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to git version as of Feb 2th 2024. This is needed for openmw
  to compile with MyGUI 3.4.2
- disabled compilation of openmw-cs (editor) as it fails
* Thu Aug 10 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 0.48.0:
  * Set openmwluadocumentor version for luadoc generation in 0.48
  * Share the dump directory for crash and freeze dumps
  * Merge branch 'macos_target_non_eol_version' into 'master'
  * Update Windows crash dump path once we know where we're logging
  * Stupid Win32 macro stuff
  * Don't put crash dumps in Temp on Windows
  * Merge branch 'font_changelog' into 'master'
  * Merge branch '0.48-changelog' into 'master'
  * Merge branch 'particles_fix' into 'master'
  * Allow OpenMW 0.48 to parse save headers from 0.49
  * backport CLAMP_TO_EDGE fix to 0.48
  * Use most recent OSG dependency to match 0.48 RC builds
  * Fix logging and config for portable setup
  * Fix build with GCC 13.1.1
  * fix for macos intel for CI
  * Merge branch 'fix_element_destroy' into 'master'
  * Use different object id for avoid shape
  * Fix integration tests job deps
  * Update cell local map on different neighbour cells
  * Use LuaUtil::cast for casting sol::object to prevent crashing
    on type mismatch in Lua scripts.
  * Add function LuaUtil::cast
  * fix macos issue
* Sun Apr 23 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 0.48.0~rc9:
  * Update file luascripts.hpp
  * Save original paths
  * Use set to track visited directories instead of removing
    duplicates
  * Don't capture temporaries by reference
  * In 0.46, SetPos was setting position of actors before physics
    simulation, and from this position movement was simulated. This
    changed with async physics merging, and at the same time
    problems started, mostly with abot's scenic travel.
- Use gcc12 till upstream fixes all missing includes
* Tue Mar 21 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 0.48.0~rc8:
  * Update AppData summary to be more concise
  * Empty-Commit to trigger pipeline
  * Ensure shader requirements are pushed at least once for subgraph
  * Revert "Attach shaders to geometry that lacks a stateset if
    necessary (bug #7251)"
  * SkyStereoStatesetUpdater was incorrectly always using reverseZ
    matrices.
  * Change assosiative order of stereo-related matrix
    multiplications to reduce FP errors.
- Changes in version 0.48.0~rc6:
  * Merge branch 'fix_gpu_osg_stats' into 'master'
  * Restore 0936d716d96cd45b3efc2d1a3697614f7f96952d
  * Changelog for osga-animation layering
  * Stop updating navmeshtool progress on first bad message
  * Remove accidental copy-paste in global.doclua
- Add BuildRequires pkgconfig(icu-i18n) and pkgconfig(icu-uc), use
  system provided libicu
* Sun Jan 22 2023 Florian "spirit" <packaging@sp1rit.anonaddy.me>
- Update to 0.48.0~rc5:
  * exremly long list of changes, see CHANGELOG.md shipped as part
    of this package in /usr/share/doc/packages/openmw/CHANGELOG.md.
  * current commit is e6b6f2c, part of the openmw-48 branch, used by
    upstream as RC5.
- Dropped obsolete patches:
  * openmw-0.47.0-gcc12.patch
  * openmw-sigaltstack.patch
* Sun Aug 14 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add openmw-0.47.0-gcc12.patch: Fix build with GCC 12 (gl#OpenMW/openmw#6744).
* Wed Nov 17 2021 Matthias Fehring <buschmann23@opensuse.org>
- Removed double source entry
* Mon Nov 15 2021 Matthias Fehring <buschmann23@opensuse.org>
- update to 0.47.0:
  * extremely long list of changes, see
    https://openmw.org/2021/openmw-0-47-0-released/
- Removed obsolete patches:
  * openmw-add-missing-include.patch
  * 0001-add-GCC-11-needed-includes.patch
  * openmw-cast-float-to-btScalar.patch
* Fri Oct 22 2021 Adam Mizerski <adam@mizerski.pl>
- Added patches:
  - openmw-sigaltstack.patch
  - openmw-cast-float-to-btScalar.patch
- Updated patches:
  - openmw-add-missing-include.patch
* Mon Jun 28 2021 Aleksa Sarai <asarai@suse.com>
- Fix builds on GCC 11. Upstream seems to have fixed this but there isn't a
  single obvious commit to backport, so just add the necessary includes to
  every file which was missing them.
  + 0001-add-GCC-11-needed-includes.patch
* Mon Nov 16 2020 malcolmlewis@opensuse.org
- Add openmw-add-missing-include.patch: Add missing algorithm
  include for later boost releases, (gh#OpenMW/openmw!2817).
- Add missing build requires on boost regex.
* Tue Aug 25 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.46.0:
  * extremely long list of changes, see
  https://openmw.org/2020/openmw-0-46-0-released/
* Sat May  2 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 0.45+git.20200318:
  * Do not write empty trade time
  * Support for radial fog (feature #4708)
  * Cleanup ownership for items in containers
  * Do not use dynamic casts when using ObjectState
  * Compare revisions by equality to support overflow
  * Support recast mesh rendering
  * Accept an extra numerical argument in GetItemCount
- Update to git fixes building with OpenSceneGraph 3.6.5
- Added _service file to download fromt github
- Added libboost_iostreams-devel to BuildRequires
* Wed Jan 29 2020 Cristian Rodríguez <crrodriguez@opensuse.org>
- Build with -fvisibility=hidden, generates better and ~3MB
  smaller executables.
* Fri Jul 12 2019 Michel Normand <normand@linux.vnet.ibm.com>
- update _constraints for PowerPC that needs more than 4.6G disk
* Sun Jun 23 2019 Maximilian Trummer <opensuse@trummer.xyz>
- update to 0.45.0
  * Non-actor objects display visual effects during spellcasting
  * Creatures without any collision box use auto-generated ones
  * Launcher: File paths of selected content files can be copied via context menu
  * Actors play casting animations during scripted spellcasting
  * As an option, barter deals permanently modify merchant disposition
  * Ranged weapons deal critical hits to unaware opponents
  * 360° screenshots of various kinds can be made
  * 'ToggleBorders' debug instruction ("tb") available in console
  * Sound generator keys in activator animations are supported
  * Some of the debug settings previously available as command line arguments can be set up in the launcher
  * Support for per-group KF animation replacers has been added
  * Shader water is rougher during bad weather
  * The number of enchanted items in a stack is shown in the Spells window
  * The actual chance of hitting the target is used for AI weapon rating instead of just the skill
  * The real potential damage of a weapon is used for its rating
  * A bonus is applied to the rating of ranged weapons if the attacker is far enough from the target
  * As an option, the Strength attribute affects Fatigue and Health damage in hand-to-hand combat
  * The logging system has been heavily reworked
  * AI no longer uses magic effects that affect hit chance if the enemy has not taken the appropriate stance
  * AI uses the root mean square of melee-weapon damage for more precise weapon rating
  * AI accounts for weapon speed when rating a weapon
  * Various vanilla GMSTs regarding combat action rating are utilised
  * 'sTo' GMST ("to") replaces hyphen in the Spellmaking menu
  * New count field in the Alchemy window allows you to brew multiple potions at the same time
  * To improve performance, actors outside of the AI processing range are no longer rendered but faded out
  * AI processing range can be configured via an in-game slider and a configuration option
  * If the animated creature model lacks a collision box, the non-animated model's collision box is used as a fallback
  * Tooltips of thrown weapons show the actual in-game damage (twice the base-record damage) the projectiles have
  * All top-bar dropdown menu options and most context menu options have icons
  * Actors are rendered in Scene view
  * Verifier functionality covers Enchantment records
  * Added a check box to execute a case-sensitive global search
  * Shift + C is default shortcut for viewing cells
  * Shift + V is default shortcut for previewing records
  * Global search has a status bar
  * Frame rate in Preview window can be limited
  * Log files are created in case of a crash
  * Previously sorted-by-ID lists, such as magic-effect lists, are now alphabetically sorted
  * As an option, base records are ignored in verifier runs
  * Already existing marker models for light sources and creature levelled lists are now used
  * All actors (not only those in active cells) restore Health and Magicka during player character rest
  * Precise times of sunrise and sunset are now recovered from the imported Morrowind INI file
  * Actors now properly aim during scripted spellcasting
  * Skills and attributes that affect trading no longer cause low selling prices if they're too high
  * Landing sound behaviour for NPCs and the player character has been reworked
  * Scripted movement of an object now adjusts the position of actors standing on top of that object
  * The last equipped item of a certain type is automatically re-equipped once a bound-item spell of the same type expires
  * Restore effects can restore drained stats
  * Attacks from unarmed, non-bipedal creatures no longer degrade armour
  * For the time being, actors are no longer allowed to activate teleport doors so that their abrupt cell change doesn't cause a crash
  * Using 'Resurrect' instruction on a dead player character fully resumes the game
  * References to non-existent classes or factions no longer crash the game
  * Weapons are visually unequipped before the start of a spellcasting stance transition
  * The player character now gets a bounty when a player follower commits a murder
  * Explicit reference calls no longer break [Tab] autocompletion in the console
  * Naked expressions starting with a member operator are no longer allowed outside of the console
  * The handling of Drain and Fortify effects for health, magicka, and fatigue has been reworked to match vanilla behaviour
  * Enemies are no longer immune to ranged attacks at very close range
  * Adding an item with a self-equipment script to an actor no longer causes a freeze
  * Actors who are placed above the ground are now snapped down at a significantly larger distance when a cell is loaded, preventing them from falling to their death
  * TrueType fonts are now properly rescaled
  * Targets are now much easier to hit with on-touch spells
  * The handling of scripted and death animations has been reworked to significantly improve mod compatibility
  * 'GetSpellEffects' scripting function can now detect zero-duration effects
  * Enemies are much easier to hit with low-reach weapons, since the intended start position of the attack raycast is now replicated
  * Scripted sleeping interruptions no longer prevent the spawning of random sleep encounters
  * Calling 'AddSoulGem' and 'RemoveSpell' scripting instructions with an extra argument no longer breaks script compilation
  * 'GetPCInJail' scripting function has been reworked to more closely match vanilla behaviour
  * Previous placeholder implementation of 'GetPCTraveling' scripting function has been replaced with a proper solution
  * Message boxes can now have newline characters in the text argument
  * Alignment of terrain texture painting has been corrected to match the vanilla look
  * Attenuation of magic light sources is now properly calculated
  * 'Goodbye' scripting function in dialogue results now makes any additional choices act like 'Goodbye'
  * 'RemoveSpellEffects' scripting instruction now also removes permanent effects
  * Movement prediction for spell aiming now uses the correct GMST to calculate the magic projectile's speed
  * Animated collision shapes are no longer erroneously optimised
  * The terrain texture blending map is now upscaled to more closely match the vanilla look
  * Issues with actors not returning to their initial position in various situations have been fixed
  * AI packages with a non-unique target no longer choose a random target with the same ID
  * Text after the last end-of-line tag is no longer shown in books to match vanilla behaviour
  * 'FixMe' script instruction has been reworked to more closely match vanilla behaviour
  * Jumping on slopes is now less restrictive, preventing the player character from getting stuck in V-shaped terrain
  * Pathgrid nodes which lie between an actor and that actor's destination are now ignored
  * Actors with an AiTravel package now stop near their target position if that position is blocked by another actor
  * [Activate] key can no longer be held down to spam Persuasion and other kinds of repeatable actions
  * Turning animations no longer reset idle animations
  * Death animations from pre-0.43.0 savegames are now forward-compatible
  * 'CenterOnCell' script instruction ("coc") now teleports the player character to the accurate door marker or exterior position for interior and exterior cells respectively
  * Faction members are now aware of faction ownership during barter
  * AiWander packages which are placed before an AiFollow package in the AI package list no longer override vital functionality of that AiFollow package
  * Key focus in containers is now automatically (re)set to the [Close] button to prevent players from accidentally stealing items
  * Spellcasting stance transitions no longer interrupt movement animations
  * OK button in the Settings window has key focus by default
  * It's no longer possible to cast an Absorb spell on oneself
  * Non-audio files no longer crash the game when the engine tries to play them
  * When there is a 'NiStringExtraData' node with MRK value in a NIF model node, only 'NiTriShape' meshes starting with "Tri EditorMarker" are ignored instead of the whole node
  * 'RotateWorld' scripting instruction now rotates objects around the correct axis, while keeping the objects' initial rotation
  * Applying the console command "Lock 0" to a door or a container now creates an unbreakable lock, like in vanilla Morrowind
  * Actors without any AI packages now properly return to their initial position after combat or pursuit
  * Guards with AiAlarm = 0 no longer attempt to arrest the player character when they observe a crime but no one reports it
  * 'Begin' and 'End' script keywords can now be followed by a comma
  * The default terrain texture no longer shines through terrain texture blending transitions
  * Broken items are now ignored when trying to equip an item via quick key
  * Actors now open doors more quickly
  * Light sources which cannot be carried no longer prevent the AI from auto-equipping shields
  * The handling of idle chances in AiWander packages has been reworked to more closely match vanilla behaviour
  * 'NotCell' dialogue condition now supports partial name matches
  * Scripted equipment now bypasses most standard equipping restrictions, e.g., those for beast races
  * When a non-player object casts an Open spell, a player crime event is triggered if the player character is detected to ensure vanilla compatibility
  * General-number formatting ("%%g") now works like in vanilla Morrowind and properly handles the fractional part
  * Cancelled AI packages are now removed from the package cache
  * Non-ASCII strings are now properly handled in the content selector and in the ESM reader
  * Silt striders in abot's "Silt Striders" mod are no longer rotated by 90 degrees
  * The behaviour of weapon-using non-bipedal creatures has been reworked to make them less helpless in certain situations
  * Actors who are vampires now display their regular record head when no vampire head is found
  * Scripted animations no longer move actors away from their initial position
  * Potential crashes in the quick-keys menu when an item is no longer available in the inventory no longer occur
  * 'Goodbye' dialogue scripting instruction now disables hyperlinks in dialogue topics
  * 'PositionCell' scripting instruction no longer tries to add local scripts to scripted items in the teleported player character's inventory twice
  * Training cap is now limited by the trainer's modified skill instead of their base skill
  * Crossbow reloading animations now only apply to the upper body
  * Crossbows now use animations for one-handed weapons as a fallback
  * Animations for turning in spellcasting stance are now used
  * Animated meshes without slashes in their full path are now properly classified as animations
  * Scripted spellcasting no longer increases the Alteration skill
  * A potential zero division in the Fatigue calculation has been removed
  * A knocked-down player character can no longer move or be moved in first-person view
  * Some issues with sun specularity in the water shader have been fixed
  * Movement animations without idle-animation fallback no longer trigger idle animations
  * The game now switches between distorted (underwater) and undistorted sound effects based on the camera position instead of the player character's head position
  * The inventory paper doll is now affected by GUI scaling
  * Items with an 'OnActivate' command present in their script (such as "cursed" items) no longer visually disappear when they are picked up in menu mode
  * Creatures no longer incorrectly flee from werewolves
  * Minimum and maximum sound ranges with zero value are now separately reset to their default ranges
  * Non-actor objects can no longer have a dialogue window opened via script
  * Dialogue topics with reserved names, e.g., "Barter" or "Repair", now behave the same as in vanilla Morrowind
  * Optimiser search for reserved node names is now case-insensitive
  * Pinned windows are now properly updated
  * Fast-travel logic now always depends on the type of the service NPC's cell instead of the destination cell type
  * The underwater viewing distance limit is no longer broken
  * The player character no longer uses headtracking in first-person view
  * The handling of player character turning animations has been improved
  * Several weapon animation inconsistencies during movement in first-person view have been fixed
  * Idle animations are no longer reset in certain situations where they should be continuous
  * If an innocent actor dies from the continuing effects of a player attack, the murder is now also reported if the player has already paid their fine
  * Attack strength is now 0 if the player spams the [Attack] button
  * The incorrect inequality operator "[]" is now interpreted as less-than operator "[" to ensure compatibility with certain mods
  * Picking a stack of gold up in menu mode now grabs the whole item stack
  * Scaling for animated collision shapes is no longer erroneously applied twice
  * Fall damage is no longer erroneously applied twice
  * The pseudo duration of instant magic effects has been adjusted in the spellmaking menu to match vanilla spell cost calculations
  * A zero division occurring in 'NiFlipController' nodes without textures has been removed
  * The flickering frequency of light sources and some light-related calculations have been fixed
  * The sneaking offset in first-person view is now also applied when switching to sneak mode in midair
  * Sneaking is no longer possible while flying
  * Recharging enchanted items now always increases the Enchant skill regardless of success or failure, like in vanilla Morrowind
  * NPC record entries Reputation, Disposition and Faction Rank are now loaded as unsigned variables
  * Sneaking stance no longer affects speed if the actor is not actually sneaking
  * 'GetPCJumping' scripting function has been reworked to match vanilla behaviour
  * "%%Name" string replacer can now be used in creature dialogue
  * Force-equipping a weapon now resets ongoing attack animations
  * HUD no longer displays an "item condition" for throwing weapons
  * Levelling up no longer fully restores health but rather applies the gained health points
  * Actors no longer fall from cliffs or run into obstacles when backing down from attackers
  * Enabling collision with 'ToggleCollision' scripting instruction ("tcl") now snaps the player character down to the ground
  * The number of known ingredient and potion effects is now determined by the modified rather than the base Alchemy skill
  * Pitch factor handling for crossbow animations has been streamlined to more closely match vanilla behaviour
  * Journal can no longer be opened while the Settings window is open
  * NPC fast-travel destination records without any data no longer crash the game upon loading
  * Declared but empty script variable lists no longer crash the game upon loading
  * The chance of a successful spell absorption is now multiplicative rather than additive, which is how the magic effect is designed in vanilla Morrowind
  * Calling 'Say' scripting instruction with non-existent sound as argument no longer breaks script compilation
  * Creatures that lack unique sounds now make use of fallback sound generator records
  * Loading bars no longer obscure message boxes but are instead moved to the centre of the screen
  * 'Revert' action now properly updates subviews
  * A native colour picker is now used on all operating systems, fixing major issues on macOS
  * 'Undo' and 'Redo' actions now keep assigned shortcuts
  * Lock status of newly opened subviews is now correctly initialised
  * Instance dragging, which was broken in 0.44.0, has been fixed
  * Skeletons of animated objects are now properly initialised
  * The Colour entry in Light Source records is now displayed as a coloured box instead of an integer number
  * Race condition in terrain code has been fixed
  * Skinning and AI optimisations
  * Support for Rapture3D OpenAL driver has been added
  * Record verifying functionality in OpenMW-CS has been revised
* Mon Jul 30 2018 mimi.vx@gmail.com
- update to 0.44.0
- drop qt_5_11-cmake.patch
  * Spell search bar implemented
  * Launcher: Advanced settings tab added
  * Implemented option for fast travel services to charge for every companion
  * Added an option to have multiple quicksaves
  * Added an option to rebalance soul gem values based only on soul value, not soul times gem value
  * OpenMW-CS: Terrain Texture Brush button implemented
  * OpenMW-CS: Edit functions for terrain texture editing mode implemented
  * OpenMW-CS: New, and more complete, icon set added
  * Daedra are now summoned when picking up cursed items through the inventory, OnActivate is now triggered even with the inventory menu open
  * Similar glyphs are now used as fallbacks when unsupported glyphs are encountered
  * Magic effects active when a save is loaded are now rendered
  * Journal alphabetical indexing now works in Russian language versions
  * Declaring OnPCHitMe in an actor’s script now prevents the actor from attacking, even in self-defense, if his Fight is equal to zero
  * Content selector now places Morrowind.esm at the beginning of the mod list, if it is present
  * Undefined weather settings now fallback to middle grey instead of pure black
  * Mods are now found if the mod directory is a parent of the installation directory
  * Flying and swimming creatures no longer use the pathgrid
  * SetPos no longer skips weather transitions, fixing transitions in mods that use SetPos to travel the player, such as Boats Mod
  * ESM files with capital-case extensions now load correctly with the launcher
  * Fixed an issue where NPCs could get stuck inside terrain/objects when the player rests
  * Combat music is now updated in menu mode
  * Extraneous carriage returns are cut from dialog output
  * SetPos can no longer place the target under terrain level
  * Fixed an issue where casting Calm Humanoid on a guard the player is resisting arrest from caused a dialog loop when trying to resist again
  * Enemies who are knocked out will no longer recover immediately
  * Imported content files are now sorted according to their dependencies, instead of just modified time
  * Scripts now support period and hyphen characters in the script name, as long as it is not the first character
  * Soul gems with trapped souls of creatures from mods that have been removed will now be empty instead of crashing the game
  * Swim animation is no longer interrupted when attacking underwater
  * An empty battle music folder now results in explore music being played in combat
  * Added a vanilla absorb spell behavior option, which is enabled by default
  * Added vanilla enchanted weaponry behavior option, which is enabled by default
  * Centroid interpolation is now used for shader lighting, fixing some graphical artifacts when using antialiasing
  * NPC base skeleton files are not longer optimized, fixes some body replacer mods
  * To prevent animation flickering, the landing animation is no longer played when the player is turning as they are landing
  * Fighting actors now face their target instead of the nearest actor
  * Weapon switch sound is no longer played when no different weapon is present to switch to
  * Guards can no longer initiate dialog with the player when the player is far above the guard
  * The correct graphical effect is now applied to armor and clothes when changing them while chameleoned or invisible
  * “Screenshot Saved” message has been removed
  * Attack range for NPC archers and spellcasters now more accurately matches vanilla behavior
  * Dialog topics are now always highlighted when first encountered
  * Fixed an FPS drop after minimizing the game during rainy weather
  * Thrown weapon projectiles now all rotate when in the air
  * Spell casting chance now displays as zero if the player does not have enough magicka to cast it
  * Fixed double activation button presses when using a gamepad
  * The player’s current class and birthsign is now the default value in the class select and bithsign select menus, rather than the first item in the list
  * Tribunal and Bloodmoon summoned creatures no longer automatically fight other followers
  * Player movement from one directional key is now nullified if the opposite directional key is also pressed
  * Wireframe mode no longer affects the map
  * Fixed a crash when quick loading from the container screen
  * Greetings are no longer added to the journal topic list
  * Merchant NPCs no longer sell ingredients from containers that they own that have zero capacity, such as plants
  * Armor condition is now taken into account when calculating armor rating
  * Removed unintended jump cooldown
  * Fixed console spam when OpenMW encounters a non-music file in the Music folder
  * Magic effects from eaten ingredients now have the correct duration
  * Arrow position is now correct in third person view during attacks for beast races
  * Players in god mode are no longer affected by negative spell effects
  * Missing ‘sAnd’ GMST no longer causes a crash
  * Root node transformation is no longer incorrectly discarded, fixing characters in the mod The Black Mill
  * The map is now updated with explored cells correctly, instead of only when the map window is opened
  * MessageBoxes now appear over the chargen menu
  * Optimizer no longer breaks LOD nodes
  * PlaceAtMe now correctly inherits the scale of the calling object
  * Resistance to magic now affects all resistable magic effects
  * Opening doors is now restricted to bipedal actors
  * Rainy weather no longer slows down the game when changing from indoors to outdoors
  * Meshes with CollisionType=Node flag are no longer ignored
  * Activate and Move keys are no longer used for GUI navigation if they are bound to mouse buttons
  * NPC negative faction reaction modifier now works correctly
  * Taking owned items is no longer considered a crime if the owner is dead
  * Torch and shield equipping behavior now is more consistent with the original game
  * Installation wizard now appends “/Data Files” if needed when autodetecting path
  * “Interior” removed from cell not found message
  * Inventory item count for very high numbers no longer shows incorrect values due to truncation
  * Using AddSoulgem no longer fills all sould gems of the specified type
  * A message is displayed if the spell a player tries to select via quickkey is missing
  * Inventory filter is now reset to All when loading a game
  * Terrain is now rendered for empty cells
  * OpenMW now handles marker definitions correctly, fixing mod Arktwend
  iniimporter no longer ignores data paths
  * Moving with zero strength no longer uses all of your fatigue
  * Camera no longer flickers when opening and closing menu while sneaking
  * Cursor now displays correctly when OpenMW is compiled against macOS 10.13 SDK
  * Item health is no longer considered a signed integer, it can no longer be negative
  * Adding items to currently disabled creatures will no longer crash the game
  * Encumbrance value is now rounded up
  * Werewolf health is now correctly calculated
  * NiLookAtController node is now ignored, like in vanilla
  * OpenMW-CS: “Original Creature” field renamed to “Parent Creature”
  * OpenMW-CS: Unchecking “Auto Calc” flag when editing an NPC record no longer causes unreasonable values to be filled in
  * OpenMW-CS: Fixed search and verification result tables to be case-insensitive when sorting
  * OpenMW-CS: “Model” column renamed to “Model/Animation”
* Tue Jun 12 2018 mimi.vx@gmail.com
- add new _constraints, build on x86_64 takes more than 2G ram
* Mon Jun 11 2018 mimi.vx@gmail.com
- add qt_5_11-cmake.patch to fix build with QT-5.11
* Sat Dec  9 2017 mimi.vx@gmail.com
- fix boost BuildRequires
* Mon Dec  4 2017 mimi.vx@gmail.com
- update to new release 0.43.0 - see CHANGELOG.md for details
* Wed Aug  2 2017 mimi.vx@gmail.com
- Update to new release 0.42.0 see CHANGELOG.md for more details
* Fri Dec 23 2016 mimi.vx@gmail.com
- Update to new release 0.41.0 see CHANGELOG.md for more details
* Mon Nov 28 2016 mimi.vx@gmail.com
- Force use of Qt5
* Sat Sep 10 2016 mimi.vx@gmail.com
- add OpenSceneGraph-plugins to requires -- fixes dds texture loading
* Fri Sep  9 2016 mimi.vx@gmail.com
- Update new release 0.40.0, for changelog see CHANGELOG.md
- dropped fix-unordered-map.patch
- moved to Qt5
- use system tinyxml
- spec-cleaned with spec-cleaner
- correctly handle desktop file
* Sun Jul 10 2016 rpm@fthiessen.de
- Added fix-unordered-map.patch to fix build with gcc >= 6.0
* Wed May  4 2016 rpm@fthiessen.de
- Update to new release 0.39.0, for change log see CHANGELOG.md or
    https://github.com/OpenMW/openmw/blob/master/CHANGELOG.md
* Tue Jan 26 2016 rpm@fthiessen.de
- Update to upstream version 0.38.0:
  * Fixed player object being deletable
  * Fixed AiCombat distance check to take into account collision box
  * Fixed saw in Dome of Kasia not hurting a stationary player
  * Fixed rats floating when killed near a door
  * Fixed kwama eggsacks pulsing too fast
  * Fixed NPC voice sound source not being placed at their head
  * Fixed crash with OpenMW install wizard
  * Fixed reseting delete flag when loading a reference from a save game
  * Fixed issues with clicking on unexpected inventory items on character doll
  * Fixed spell absorption to apply once per effect
  * Fixed enchantment merchant items reshuffling every time barter is clicked
  * Fixed not being able to resurrect the player through the console if health is zero
  * Fixed projectile weapon behavior when underwater
  * Fixed not being able to use keywords in strings for message boxes
  * Fixed items not sinking when dropped underwater
  * Fixed crash when onPcEquip script removes the equipped item
  * Fixed dialog not triggering correctly in Julan Ashlander Companion mod
  * Fixed tooltips for Health, Magicka, and Fatigue showing in the Options menu when bars aren't visible
  * Fixed guards accepting gold for crimes even when you don't have enough
  * Fixed Show Owned option affecting tooltips that are not objects
  * Fixed player sound source being at the feet
  * Fixed not being able to replace interactive message boxes
  * Fixed fatal error on OpGetTarget when the target has disappeared
  * Fixed first person rendering glitches with high field of view
  * Fixed crash on new game at character class selection
  * Fixed RigGeometry bone references to be case-insensitive
  * Fixed NPCs using wrong sound when landing
  * Fixed missing journal textures without Tribunal and Bloodmoon installed
  * Fixed multiple AiFollow packages causing the distance to stack
  * Fixed creature dialogs not being handled correctly
  * Fixed crash when entering Holamayan Monastery with mesh replacer installed
  * Fixed dreamers spawning too soon
  * Fixed Next/Previous Weapon/Spell and Ready Spell working as a werewolf
  * Fixed being able to soultrap a creature more than once
  * Fixed summoned creatures and objects disappearing at midnight
  * Fixed gamecontrollerdb file being created as a txt instead of a cfg
  * Fixed "same race" dialog functions never triggering
  * Fixed dialog choice condition issue
  * Fixed body part rendering when in a pose
  * Fixed reversed sneak awareness check
  * Fixed positional sound acceleration issue
  * Fixed fatal error when LandTexture is missing
  * For all changes see also CHANGELOG.md or
    https://github.com/OpenMW/openmw/blob/master/CHANGELOG.md
* Tue Jun  9 2015 devel.suse@gmail.com
- Update to upstream version 0.36.1:
  * Fixed additional startup scripts failing to launch
  Known Issues:
  * Crash when trying to view cell in render view in OpenMW-CS on OSX
  * Crash when switching from full screen to windowed mode on D3D9
* Sat May 23 2015 devel.suse@gmail.com
- Change libffmpeg-devel to ffmpeg-devel in .spec file due to
  new dependency package name
* Mon Mar 16 2015 devel.suse@gmail.com
- Update to upstream version 0.35.1:
  * Implemented being able to dress corpses (you weirdos)
  * Implemented checking Cmake sets correct MSVC compiler settings for release build
  * Implemented default values for mandatory global records
  * Implemented basic joystick support
  * Implemented a progress bar for Morrowind.ini import progress in the launcher
  * Implemented passage of time indicator when training or serving jail time
  * Fixed a crash caused by a land record without data
  * Fixed creatures with no skeleton base causing a crash
  * Fixed engine becoming unresponsive when trying to use equip next/previous with an empty inventory
  * Fixed error caused by relying on subrecord order when reading content files
  * Fixed sun trajectory
  * Fixed stolen items handling to match vanilla Morrowind
  * Fixed Divine Intervention sending the player to the wrong place in some cases
  * Fixed telekinesis not working to avoid traps
  * Fixed combat AI for unreachable enemies
  * Fixed object scale being considered in the Move instruction
  * Fixed multi-effect spells with different ranges not all applying
  * Fixed launcher not responding to Ctrl+C command from the terminal
  * Fixed drag-and-drop creating duplicate content files in the launcher when Alt is pressed
  * Fixed addon files with no dependencies not showing in the launcher
  * Fixed Detect Animal detecting dead creatures
  * Fixed Cmake not respecting LIB_SUFFIX
  * Fixed changing active magic holstering magic hands
  * Fixed switching spells with next or previous while holding shift raising the delete spell dialog
  * Fixed regression causing ignored clicks on the HUD mini-map
  * Fixed instant restore effect behavior
  * Fixed CE restore attribute items permanently boosting the stat they restore
  * Fixed being able to fall off the prison ship
  * Fixed wrong starting position in "Character Stuff Wonderland"
  * Fixed plugin load order being sorted incorrectly when importing Morrowind settings
  * OpenMW-CS: Fixed skills saving incorrectly
  * OpenMW-CS: Fixed file extension inconsistency
  Known Issues:
  * Crash when trying to view cell in render view in OpenMW-CS on OSX
  * Crash when switching from full screen to windowed mode on D3D9
- Drop openmw-lib-suffix.patch (fixed upstream)
* Sat Mar  7 2015 devel.suse@gmail.com
- Change datadir to /usr/share/openmw
* Tue Feb 17 2015 devel.suse@gmail.com
- Add /sbin/ldconfig call to .spec
* Tue Feb 17 2015 devel.suse@gmail.com
- Add openmw-lib-suffix.patch
* Tue Feb 17 2015 devel.suse@gmail.com
- Update to upstream version 0.35.0:
  * Implemented Calm effect removing combat packages
  * Implemented first stages of ess-Importer, an importer for vanilla Morrowind save games, this feature is not complete
  * Implemented previous/next weapon and spell equipping hotkeys
  * Implemented XYZ rotation keys support
  * Implemented AI fast-forward
  * Implemented NPC drowning while knocked out
  * Implemented setting for exterior cell grid size
  * Implemented some leveled list script functions
  * Implemented testing dialog scripts with --script-all
  * Implemented NPC lookAt controller
  * Implemented handling initial state of particle system
  * Implemented a warning when loading a savegame that depends on non-existent content files
  * Implemented conversion of global map exploration overlay for ess-Importer
  * Implemented command line option to load a save game
  * Implemented new display of load order problems in the Data Files tab of the launcher
  * Fixed some sound effects playing at very loud levels
  * Fixed transparency issues with some UI elements
  * Fixed launcher handling of master and plugin selections loaded from openmw.cfg
  * Fixed water display issue on AMD cards
  * Fixed a text display issue when highlighting words in dialog
  * Fixed a launcher crash when a content file is locked
  * Fixed being able to stand on top of hostile creatures
  * Fixed creatures climbing on top of the player
  * Fixed AITravel to more accurately emulate vanilla
  * Fixed some moon display issues
  * Fixed place-able items having collision
  * Fixed AIFollow distance for groups of multiple followers
  * Fixed some staircase climbing issues in Vivec
  * Fixed permanent magic effects not being saved in savegames
  * Fixed crash due to zero-sized particles
  * Fixed a model scaling issue
  * Fixed activated enchanted item magic not being saved in savegames
  * Fixed a crash caused by Ogre shadow handling
  * Fixed not being able to equip a shield with a two-handed weapon
  * Fixed an issue with player fall height when stepping down
  * Fixed an error-handling issue preventing the Sword of Perithia mod from loading
  * Fixed launcher reseting alterations made to the mod list order
  * Fixed some issues with NPC idle voices
  * Fixed vampire corpses standing up when being looted
  * Fixed spell cost not highlighting on mouseover
  * Fixed tooltips still showing when menu is toggled off
  * Fixed rain effect showing while underwater
  * Fixed extreme framedrop when running into certain corners
  * Fixed mod "Shrines - Restore Health and Cancel Options" restore health option not working
  * Fixed animation groups for light and door objects
  * Fixed slaughterfish not attacking partially submerged enemies
  * Fixed air movement mechanics
  * Fixed handling of NPCs with missing hair/head models
  * Fixed position flicker after an animation ends
  * Fixed supporting region names in cell dialog filter for mod "Julan Ashlander Companion"
  * Fixed issues with animated collision shape
  * Fixed mod "Morrowind Rebirth 2.81" causing Balmora bridges to not have collision
  * Fixed summons to reset when the spell is recast
  * Fixed equipment update when unequipping non-related items removing ammunition
  * Fixed not falling back to the top-level directory when looking for resources
  * Fixed mod pathgrids not overwriting the existing pathgrid
  * Fixed a gameplay stopper with the Russian version of the ChaosHeart mod
  * Fixed the resurrect function to work correctly
  * Fixed functionality to allow mods to overwrite existing records in the IndexedStore
  * Fixed an issue with extra bytes to fix an error with the mod "Animated Morrowind - Expanded"
  * Fixed multi-character comparison operators to allow spaces
  * Fixed handling deleted references to fix the "Gateway Ghost" quest
  * Fixed summoning to allow multiple instances of the same creature by using different spells
  * Fixed pathgrid in the (0, 0) exterior cell not loading
  * Fixed actor original position not being saved with the wander package
  * Fixed creatures not receiving fall damage (shouts to this amazing bug description: http://bugs.openmw.org/issues/2201 )
  * Fixed enchant cost issue
  * Fixed handling of missing spells and factions to be more graceful
  * Fixed several book display issues
  * Fixed some script compilation issues
  * Fixed scale field for creatures not being handled
  * Fixed being able to use enchantments from items that failed to equip
  * Fixed handling names for helmet models
  * Fixed some NPCs not attacking when they are pickpocketed
  * Fixed chargen race preview head default orientation
  * Fixed animations with no loop keys being looped
  * Fixed spell making to allow adding multiple attribute/skill effects
  * Fixed crash when northmarker has been disabled
  * Fixed area effect on touch spell behavior
  * Fixed dwarven crossbow clipping through the ground when dropped
  * Fixed torch animation playing when torch is hidden
  * Fixed sneak re-applying after attacking an NPC
  * Fixed handling for bipedal creatures without weapons
  * Fixed conflict resolution for conflicting dialog topics
  * Fixed tab completion for exterior cell names
  * Fixed third person view being preserved in save games
  * Fixed save/load progress bar behavior
  * Fixed TogglePOV not being bindable to the Alt key
  * Fixed exception for empty dialog topics
  * Fixed PlaceAt function's count behavior
  * Fixed map notes to display on the door marker leading to the cell with that note
  * Fixed some UI issues to be better compatible with UI overhaul mods
  * Fixed an issue with leveled item arguments
  * Fixed enchanted arrows being added to the victim
  * Fixed missing sound for drawing throwing weapons
  * Fixed guards detecting invisible players
  * Fixed camera not being attached properly when player becomes a vampire
  * Fixed visual effects showing on the overhead map
  * Fixed health modifier not resetting when an actor dies
  * Fixed God Mode to not require magicka when casting spells
  * Fixed attachArrow exception when changing weapon
  * Fixed error when disabled objects are moved between cells
  * Fixed scripts with names starting with digits failing to compile
  * Fixed click activate and de-activate behavior in the Data Files list
  * Renamed "profile" to "content list" in the launcher
  * Added comments to the local/global openmw.cfg files to clarify their identity
  * OpenMW-CS: Implemented clicking on a script error in the report window to set the cursor in the script editor to the
  respective line/column
  * OpenMW-CS: Implemented deleting selected rows from result windows
  * OpenMW-CS: Fixed window opening issue when the config file doesn't exist
  * OpenMW-CS: Fixed skills to allow values other than 0 through 99
  * OpenMW-CS: Fixed an issue with not launching when another instance was falsely detected as running
  * OpenMW-CS: Fixed a crash on launch when OpenMW is not installed as well
  * OpenMW-CS: Cleanup for the Opening Window and User Settings Window
  Known Issues:
  * Crash when trying to view cell in render view in OpenCS on OSX
  * Crash when switching from full screen to windowed mode on D3D9
* Wed Jan 21 2015 devel.suse@gmail.com
- Update to upstream version 0.34.0:
  * Implemented ClampMode in NiTexturingProperty, fixes some floating plant textures
  * Implemented INI-importer for the launcher
  * Implemented "encoding" option in the launcher
  * Disabled third-person zoom by default due to usability issues (can be re-enabled in settings file)
  * Fixed several launcher and installation issues
  * Fixed issue with BIK video/audio playback sync
  * Fixed NPCs ignoring player invisibility when engaged in combat
  * Fixed long class names being cut off in the UI
  * Fixed running while levitating draining fatigue
  * Fixed handling of disabled plugins
  * Fixed ToggleMenus not closing dialog windows
  * Fixed crash when calling getDistance on items in the player's inventory
  * Fixed the Buglamp tooltip showing the item weight
  * Fixed slave crime reaction to PC picking up slave's bracers
  * Fixed Dremora death animation
  * Fixed Mansilamat Vabdas's floating corpse
  * Fixed bounty not being completely removed after the Larius Varro Tells A Little Story quest
  * Fixed silenced enemies attempting to cast spells
  * Fixed The Warlords quest
  * Fixed sneak attacks on hostiles causing a bounty
  * Fixed a crash caused by incorrect handling of getPcRank and similar defines
  * Fixed pause in Storm Atronach animation
  * Fixed a bug in TerrainGrid::getWorldBoundingBox
  * Fixed crash on exceptions while adding startup scripts
  * Fixed AiWander path finder hang when quickly changing cells
  * Fixed crash when playing OGG files
  * Fixed Dagoth Gares talking to the player even when he is not there
  * Fixed overflow exploit in bartering
  * Fixed a crash when maximizing the window with the race selection dialog open on D3D9
  * Fixed script command "Activate, player" not working
  * Fixed buttons only lighting on hover over their label
  * Fixed Slowfall effect being too weak
  * Fixed several skeleton/bone model and animation issues
  * Fixed script handling to treat the [ character as whitespace
  * Fixed a crash in character preview for non-existing meshes
  * Fixed abrupt transition when ash storms end
  * Fixed mouse movements being tracked during video playback
  * Fixed a crash on exit
  * Fixed being able to attack Almalexia during her final monologue
  * Fixed the frame time cap not being applied to Ogre's ControllerManager
  * Fixed recalculation of Magicka to be less aggressive
  * Fixed Azura's spirit fading away too fast
  * Fixed Magicka becoming negative
  * Fixed health so it drops to 0 if it goes below 1.
  * Fixed floating hairs in Westly's Pluginless Head And Hair Replacer
  * Fixed some issues with mods that use conversation scripts to update the PC
  * Fixed graphical issues with Morrowind Grass Mod
  * Fixed issues with renaming profiles in the launcher
  * OpenCS: Implemented rendering cell markers
  * OpenCS: Implemented double-click functionality in tables
  * OpenCS: Implemented user settings dialog grouping, labeling, and tooltips
  * OpenCS: Implemented editing positions of references in the 3D scene
  * OpenCS: Implemented edit mode button on the scene toolbar
  * OpenCS: Implemented user setting for showing the status bar
  * OpenCS: Improved the layout of the user settings dialog
  * OpenCS: Fixed script compiler sometimes failing to find IDs
  * OpenCS: Fixed verifier not handling Windows-specific path issues when dealing with resources
  * OpenCS: Fixed display of combat/magic/stealth values
  * OpenCS: Fixed saving
  * OpenCS: Fixed exception caused by following the Creature column of a SoundGen record
  * OpenCS: Fixed MDL subrecord error
  * OpenCS: Fixed coordinate and rotation editing
  * OpenCS: Fixed several window and view handling issues
  * OpenCS: Fixed loading plugins with moved references, implementation of moved references still pending
  * OpenCS: Fixed a crash when closing cell render window on OSX
  Known Issues:
  * Crash when trying to view cell in render view in OpenCS on OSX
  * Crash when switching from full screen to windowed mode on D3D11
- Drop openmw-cmake-OGRE-lib-path.patch
- Drop openmw-opencs-fix-saving.patch
* Mon Jul 28 2014 devel.suse@gmail.com
- add openmw-opencs-fix-saving.patch and removed workaround
* Mon Jul 28 2014 devel.suse@gmail.com
- fix OpenCS saving ability
* Thu Jul 17 2014 devel.suse@gmail.com
- Update to upstream version 0.31.0:
  * Implemented periodic cleanup/refill
  * Implemented precipitation and weather particles
  * Implemented dialogue merging
  * Implemented saving missing creature state
  * Implemented saving fog of war state
  * Implemented NPCs and creatures fighting each other
  * Implemented murder crime
  * Implemented Sneak skill enhancements
  * Implemented item restock handling
  * Implemented save game levelled creature handling
  * Implemented modFactionReaction script instruction
  * Implemented animated main menu support
  * Implemented saving walk/run toggle state
  * Implemented save game naming changes
  * Implemented a delete button on the load game menu
  * Implemented using journal while in dialog
  * Implemented battle music while in combat
  * Implemented follower fast travel
  * Implemented disposition and distance based aggression
  * Fixed clouds and weather to better match vanilla Morrowind
  * Fixed local map not showing objects that span multiple cells
  * Fixed CenterOnCell behavior to better match vanilla Morrowind
  * Fixed local and world map display issues
  * Fixed water being luminescent at night
  * Fixed launcher not supporting non-latin paths on Windows
  * Fixed background tracks repeating
  * Fixed door animation behavior when leaving a cell
  * Fixed disabled stronghold statics showing on the world map
  * Fixed excessive vram usage after extended play
  * Fixed dead body collision behavior
  * Fixed several character creation issues
  * Fixed various issues with jumping
  * Fixed delay on reflection effects
  * Fixed being able to interact with the world during Wait/Rest dialog
  * Fixed being able to drop items inside walls and ceilings
  * Fixed corpses changing orientation when re-entering a cell
  * Fixed several footstep sound issues
  * Fixed several dialog link issues
  * Fixed broken dialog topics in Russian version
  * Fixed summoned creature duration issue
  * Fixed crimes against hostile NPCs issue
  * Fixed creature run speed formula
  * Fixed weakness to fire not working with fire damage in the same spell
  * Fixed NPCs killing each other while attacking the player
  * Fixed Bittercup script not working on 'Take' option
  * Fixed case sensitivity for .bsa files
  * Fixed crash when loading a save after being killed
  * Fixed jumping not being disabled when showing message boxes
  * Fixed binding keys to uncommon characters
  * Fixed container selection changing based on mouse pointer position
  * Fixed a load/save issue with dynamic records
  * Fixed double paste into console
  * Fixed crash with D3D9 shaders
  * Fixed incorrect slope climb allowing the player to skip chargen
  * Fixed slaughterfish detecting player when player is out of the water
  * Fixed error when loading Animated Morrowind
  * Fixed NPC footsteps persisting after killing a moving NPC
  * Fixed previously equipped items not shown as unequipped after attemping to sell them
  * Fixed actors ignoring vertical axis when deciding to attack
  * Fixed blank toggle option for shadows in options menu
  * Fixed Ashlands being visible during new game loading process
  * Fixed guards prompting with punishment options after player resists arrest with another guard
  * Fixed a gate activation in TR
  * Fixed dependent files not getting disabled in launcher when parent is disabled
  * Fixed several code fragments
  * Fixed incorrect voice type playing on sleep interrupt
  * Fixed save games not showing in menu in certain cases
  * Fixed lights without a model not working
  * Fixed Animation Compilation mod not working properly
  * Fixed third party SL_Pick01.nif not working
  * Fixed being unable to exit dialog after stealing in front of Sellus Gravius
  * Fixed installs to /usr/local not working
  * Fixed failure to load save if one of the content files is disabled
  * Fixed crash on loading Siege at Firemoth
  * Fixed Arkngthand door not opening
  * Fixed Segfault when modifying view distance in options
  * Fixed apostrophe and dash characters not displaying in French version
  * Fixed display issue with icon background for magic items
  * Fixed display issue with coin icon on level up dialog
  * Fixed Alt+F4 not working in Windows
  * Fixed changing ring behavior
  * Fixed robes hiding pauldrons
  * Fixed button orientation on some shrine dialogs
  * Fixed items floating in the air when dropped onto corpses
  * Fixed forearms not rendering on Argonian females
  * Fixed alchemy allowing making potions from two of the same item
  * Fixed Max Sale button behavior
  * Fixed rest until healed for characters with stunted magicka
  * Fixed empty travel window displaying during new game sequence
  * Fixed save game permission issue
  * Fixed crash when loading The Underground 2 mod
  * Fixed ignoring additional splash screens
  * Fixed perpetual save load issue
  * Fixed error with Skyrim: Home of the Nords
  * Fixed many script instruction behaviors
  * Fixed read skill books not being saved in save game
  * Fixed unusable items being able to get bound to hotkeys
  * Fixed text variables in journal topic list
  * Fixed repeating swings on friendly NPC counting as additional crimes
  * Fixed lack of punishment for stealing priceless items
  * Fixed door marker at Jobasha's Rare Books spawning PC in the air
  * Fixed topic selection menu to be wider
  * Fixed items dropped on rug being inaccessible
  * Fixed crime for dropping and taking looted items
  * Fixed location of dropped arrows and bolts
  * Fixed security trainers offering acrobatics instead
  * Fixed punishment dialog displaying instead of load when killed by a guard
  * Fixed script error in SkipTutorial
  * Fixed bad lighting when using morrowind.ini generated by MGE
  * Fixed mobile Heart of Lorkan
  * Fixed keybindings not saving
  * Fixed apathetic Dura Gra-Bol
  * Fixed Morrowind Patch preventing interior cell load
  * Fixed item value on tooltip
  * Fixed death count not storing in savegame
  * Fixed submerged portion of weapon not rendering when partially submerged
  * Fixed enemies attacking while dying
  * Fixed ESM error with INFO
  * Fixed projectiles shot at player ending up in inventory
  * Fixed monsters respawning on top of each other
  * Fixed dialog box opening on follower NPC when NPC is dead or game is paused
  * Fixed floating paralyzed cliffracers
  * Fixed message boxes not clearing when loading a different save game
  * Fixed underwater sound sometimes playing when transitioning from an interior
  * Fixed spell projectiles not colliding with water surface
  * Fixed console error message when information is refused by an NPC
  * Fixed being unable to remove arrow during Bloodmoon: The Ritual of Beasts quest
  * Fixed being unable to talk to Carnius Magius in Bloodmoon
  * Fixed crash when attempting to play a non-music file
  * Fixed world map not being centered on player in certain cases
  * Fixed arrow behavior in wait/rest dialog
  * Fixed kills not filling werewolf hunger
  * Fixed detect life behavior while a werewolf
  * Fixed crash during The Shrine of the Dead mission in Tribunal
  * Fixed selected text background color in the console
  * Fixed handling extra arguments given to script instructions
  * Fixed NPCs taunting after they are dead in An Assassionation Attempt quest
  * Fixed game halt when attacked by Centurion Archers
  * Fixed quest journal when completing The Missing Hand quest
  * Fixed several issues with the Dome of Serlyn
  * Fixed bounty being calculated from actual item value instead of highest value
  * Fixed terrain turning invisible on top of Red Mountain
  * Fixed steam appearance in Cave of the Hidden Music quest
  * Fixed display issues when picking up a stack of items, holding enter, and moving the mouse
  * Fixed Draugr and Riekling attacks
  * Fixed Bonewolf animation
  * Fixed particle effects being paralyzed when the player is paralyzed
  * Fixed Crimson Plague quest not updating when Gedna Relvel is killed
  * Fixed failed save game when saving in Old Mournhold: Forgotten Sewer
  * Fixed segfault when making Drain/Fortify Skill spells
  * Fixed case where game wouldn't switch to fullscreen
  * Fixed Morrowind Rebirth duplicate objects/vanilla objects not being removed
  * Fixed case where paralysis and switching view modes would prevent death notification
  * Fixed an alt+tab segfault
  * Various code maintenace and cleanup
  * OpenCS: Implemented object rendering in cells
  * OpenCS: Implemented configuration setup
  * OpenCS: Implemented threaded loading
  * OpenCS: Implemented cell record saving
  * OpenCS: Implemented body part table
  * OpenCS: Implemented enchantment effect table
  * OpenCS: Implemented deleting referenceables
  * OpenCS: Fixed Combat/Magic/Stealth values for creatures are not displayed
  * OpenCS: Fixed segfault after 'new' or 'load'
  * OpenCS: Fixed deleting Record Filter line not reseting the filter
  * OpenCS: Fixed crash when drag and dropping text
  * OpenCS: Fixed bogus filter being created when dragging multiple records to the filter bar of a non-applicable table
  Known Issues:
  * Switching from fullscreen to windowed mode on Windows 7 or 8.1 while using the D3D9 renderer causes a crash
  Was this fixed?
  * Bug #1567: Editor: Deleting of referenceables does not work
- Known issue: OpenCS saving project doesn't work
* Wed Jul 16 2014 devel.suse@gmail.com
- Add docs and opencs content editor to spec
* Wed Jun 18 2014 devel.suse@gmail.com
- Update to upstream version 0.30.0:
  * Implemented Ranged Combat
  * Implemented Sneaking Skill icon
  * Implemented Crime and Punishment
  * Implemented correct trader gold handling
  * Implemented AIFollow package on summoned creatures
  * Implemented run stance in the AIFollow package
  * Implemented all NPCs in the area attacking the player when the player attacks one
  * Implemented terrain threading
  * Implemented correct GUI save/load progress bars
  * Implemented saving the weather state in save games
  * Implemented class creation form remembering previous changes
  * Implemented quicksave, quickload, and autosave
  * Implemented deleting saves
  * Implemented bribe gold being placed into the NPCs inventory
  * Implemented saving quick key bindings
  * Implemented NPCs returning to their default position after pursuing the player for a crime
  * Implemented vertical axis navigation for flying and swimming creatures
  * Implemented functionality for NPCs to evade each other when walking around
  * Fixed extreme shaking that could occur during cell transitions while moving
  * Fixed crash when a non-existent content file is added to openmw.cfg
  * Fixed OpenMW allowing resting/using a bed while in combat
  * Fixed crime punishment in the Census and Excise Office at the start of a new game
  * Fixed evidence chests not re-locking after new evidence is put in them
  * Fixed NPCs still attacking after punishment is served
  * Fixed taking items from a corpse being considered a crime
  * Fixed some creatures not being able to get close enough to attack
  * Fixed dead creatures dying again each time the player enters the cell
  * Fixed input manager state not being handled correctly when loading a save
  * Fixed crash when trying to get LOS of disabled NPC
  * Fixed incorrect inventory behavior before inventory is activated in a new game
  * Fixed NPCs not equipping torches in dark interiors
  * Fixed mouse wheel scrolling too fast in race selection
  * Fixed doors being blocked by NPCs
  * Fixed repair/charge indicators not updating
  * Fixed scribs not defending themselves
  * Fixed creatures life bar not always being empty when they are dead
  * Fixed creature and hand to hand attacks not increasing armor skill
  * Fixed undead and mechanical creatures bleeding red blood
  * Fixed Tarhiel never falling
  * Fixed script variables not being saved
  * Fixed custom class names not being handled properly in save games
  * Fixed NPCs stuttering when walking indoors
  * Fixed menu appearing when trying to skip intro movie
  * Fixed NPCs getting stuck when they run into each other
  * Fixed health bar showing permanently when running BTB-Settings
  * Fixed guard killing PC when Khajiit race is selected when running BTB-Character
  * Fixed HUD weapon icon showing a fist after loading a save, when a weapon is equipped
  * Fixed guild rank not showing in dialogue
  * Fixed flash of blue when sneaking and opening a container or the inventory
  * Fixed incorrect level-up class image when using a custom class
  * Fixed mis-aligned buttons on quit menu
  * Fixed an NPC stuck hovering in a jumping animation
  * Fixed crash when loading the Big City esm file.
  * Fixed mis-aligned dialogue topic list when scrolling
  * Fixed certain faction memberships not storing in saved games
  * Fixed pasting text always inserting at the end of a text box, instead of at the cursor
  * Fixed conversation loop when asking about "specific place" in Vivec
  * Fixed Caius not leaving at the start of the "Mehra Milo and the Lost Prophecies" quest
  * Fixed map markers not being saved in save games
  * Fixed "ring_keley" causing exception
  * Fixed open dialogues not being closed when loading a game
  * Fixed some collision geometry cleanup
  * Fixed a special case script instruction for the Athyn Sarethi mission
  * Fixed an improper handling of a special NIF format case that caused problems with the Pluginless Khajiit Head Pack
  * OpenCS: Implemented region map context menu
  * OpenCS: Implemented region map drag & drop
  * OpenCS: Implemented scene subview drop
  * OpenCS: Implemented preview subview
  * OpenCS: Implemented OGRE integration
  * OpenCS: Implemented Dialogue Sub-Views
  * OpenCS: Implemented lighting modes
  * OpenCS: Implemented different camera navigation modes
  * OpenCS: Refactored user settings
  * OpenCS: Fixed failure when dropping a region into the filter of a cell subview
  * OpenCS: Fixed exception when loading files
  Known Issues:
  * Character generation can be skipped
  * Some items can be stolen without raising an alarm
  * Sound may be disabled on videos in Windows
* Mon Apr  8 2013 devel.suse@gmail.com
- Update to upstream version 0.22.0:
  * Implemented Active Spell Icons
  * Implemented walking, running, and swimming animation
  * Implemented support for ESPs and multiple ESMs
  * Implemented proper collision shapes for NPCs and creatures
  * Implemented lights that behave more like vanilla Morrowind
  * Implemented importing BSA files as part of the settings imported by the config importer
  * Implemented zoom in vanity mode
  * Implemented potion/ingredient effect stacking
  * Implemented object movement between cells
  * Implemented closing message boxes by pressing the activation key
  * Implemented random persuasion responses
  * Implemented closing message boxes when enter is pressed
  * Use rendered object shape for physics raycasts
  * Improved the race selection preview camera
  * Class and Birthsign menus options are now preselected
  * Disabled dialog window until character creation is finished
  * Decoupled water animation speed from timescale
  * Changed underwater rendering to more closely resemble vanilla Morrowind
  * Hid potion effects until discovered
  * Finished class selection-dialogue
  * Re-factored Launcher ESX selector into a re-usable component
  * Various fixes and implementations for the script compiler
  * Fix for a keyboard repeat rate issue
  * Fix for errant character outline on water in 3rd person
  * Fix for duplicate player collision model at origin
  * Fix for dialogue list jumping when a topic is clicked
  * Fix to prevent attributes/skills going below zero
  * Fix for global variables of type short being read incorrectly
  * Fix for collision and tooltip on invisible meshes
  * Fix for CG showing in Options when it is not available
  * Fix for crash when Alt-tabbing with the console open
  * Fix for pick up sound playing when object cannot be picked up
  * Fix for moving left or right canceling auto-move
  * Fix for gender being swapped (woops!)
  * Fix for footless guards
  * Fix for waterfalls not rendering at a certain distance
  * Fix for crash in “Mournhold, Royal Palace”
  * Fix for not finding non-DDS textures
  * Fix for some meshes being invisible from above water in Bloodmoon
  * Fix for Messagebox causing assert to fail
  * Fixes for Launcher file path selection
  * Fixes for missing/incorrect UI graphical elements
  * Fixes for various transparency rendering issues
  * Fixes fo various character generation UI issues
  * Fixes for config import in Launcher
  * Fixes for various new issues discovered when handling mod content
  * Various code cleanup
* Thu Feb 21 2013 devel.suse@gmail.com
- Update to upstream version 0.21.0:
  * Various dialogue, trading, and disposition fixes and improvements
  * Torch flickering improved to better match vanilla Morrowind
  * Fix for attribute fluctuation when infected with Ash Woe Blight
  * Adjusted activation range to better match vanilla Morrowind
  * Fixes for the Journal UI
  * Fixed crash caused by Golden Saint models
  * Fix for beast races being able to wear shoes
  * Fix for background music not playing
  * Fix for meshes without certain node names not being loaded
  * Fix for incorrect terrain shape on inital cell load
  * Fix for MWGui::InventoryWindow creating a duplicate player actor at the origin
  * Added video playback
  * Added support for escape sequences in message box and dialogue text
  * Added AI related script functions, note that AI is not functional yet
  * Implemented fallbacks for necessary ini values in the importer, unused in OpenMW as of yet
  * Implemented execution of scripts of objects in containers/inventories in active cells
  * Cell loading performance improvements
  * Removed broken GMST contamination fixing mechanism
  Known Issues:
  * No sound when playing videos on OS X
  * Extreme shaking may occur during cell transitions for some users (enable anti-aliasing as a possible workaround)
  * Launcher crash on OS X < 10.8
* Wed Feb 13 2013 devel.suse@gmail.com
- Update to upstream version 0.20.0:
  * Implemented all missing dialogue filters
  * Implemented Mercantile skill
  * Implemented Persuasion dialogue
  * Initial implementation of AI package classes
  * Implemented 2nd layer for Global map
  * Implemented Animation pausing while game is paused
  * Implemented Player race now changes visually during character creation
  * Fixed Cell reloading when using teleport doors that link to the same cell
  * Fixed “0 a.m.” to display as “12 a.m.”
  * Fixed text persisting in the “name” field of the potion/spell creation window
  * Fixed starting date of new games
  * Fixed console window close behavior
  * Fixed container window formatting to better accommodate long item names
  * Fixed some topics not automatically being added to the known topic list
  * Fixed auto-move working despite DisablePlayerControls being set
  * Fixed rest dialogue opening again after resting
  * Fixed double removal of ingredients when creating potions
  * Various engine code and scripting improvements
  Known Issues:
  * Extreme shaking may occur during cell transitions for some users (enable anti-aliasing as a possible workaround)
  * The disposition implementation is severely broken and will give wrong numbers in many cases
  * Entering a cell containing a Golden Saint model will crash the game
  * A journal regression causes journal updates to not display correctly
* Sun Oct 14 2012 devel.suse@gmail.com
- Update to upstream version 0.18.0:
  * Implemented Level-Up dialog
  * Implemented Hide Marker, fixes big black blocks
  * Implemented Hotkey dialog
  * Implemented Keyboard and Mouse bindings, input system rewritten
  * Implemented Spell Buying Window
  * Added support for handling resources across multiple data directories
  * Implemented Object Movement/Creation script instructions
  * Initial AI framework implemented
  * Implemented eating Ingredients
  * Implemented Door markers on the local map
  * Implemented using Keys to open doors/containers
  * Implemented Loading screens
  * Implemented Inventory avatar image and race selection head preview (note that only default Dunmer male displays at the moment)
  * Fixed the size of Preferences menu buttons
  * Fixed Hand-to-hand always being 100
  * Fixes for NPC and character animation
  * Fix for sound coordinates
  * Fix for exception when drinking self-made potions
  * Fix for clothes showing up in 1st person
  * Fix for weird character on door tooltips
  * Collision fixes
  * Fix for “onOfferButtonClicked” crash
  Known Issues:
  * The launcher can crash on OS X versions < 10.8, this will be fixed in version 0.19.0
  * “Shaking screen effect” can occur on cell change
* Sun Sep 23 2012 devel.suse@gmail.com
- added .rpmlintrc file to skip "devel-files-in-no-devel-package"
- now game should be run from wrappers: openmw.sh and omwlauncher.sh
* Tue Sep 18 2012 devel.suse@gmail.com
- Update to upstream version 0.17.0:
  * Fixes for physics shapes and dark textures
  * Fix for character normals
  * Fix for laggy input on OS X
  * Added support for objects crossing cell borders
  * Re-implemented dropping items
  * Implemented a Main Menu
  * Implemented Camera Modes and proper Player control
  * Added support for object rotation and scaling
  * Fix for NIF material sharing
  * Implemented potion usage
  * Implemented skill gain backend
  * Implemented Drain/Fortigy dynamic Stats/Attributes magic effects
  * Fix for various crashes and errors
  * Fixes for memory leaks
  * Various improvements for console scripts
  * Various code cleanup and improvements
  Known Issues:
  * Activating a bed can lock up the game
  * There is a minor memory leak that will be fixed in 0.18.0
* Sun Jul  1 2012 devel.suse@gmail.com
- Initial package creation
